pub struct AuditLogEvent {
pub actor: AuditLogEventActor,
pub context: AuditLogEventContext,
pub created_at: DateTime<Utc>,
pub details: AuditLogEventDetails,
pub event_category: String,
pub event_type: String,
pub gid: String,
pub resource: AuditLogEventResource,
}Expand description
An object representing a single event within an Asana domain.
Every audit log event is comprised of an event_type, actor, resource, and context. Some events will include additional metadata about the event under details. See our currently supported list of events for more details.
Fields
actor: AuditLogEventActorThe entity that triggered the event. Will typically be a user.
context: AuditLogEventContextThe context from which this event originated.
created_at: DateTime<Utc>The time the event was created.
details: AuditLogEventDetailsEvent specific details. The schema will vary depending on the event_type.
event_category: StringThe category that this event_type belongs to.
event_type: StringThe type of the event.
gid: StringGlobally unique identifier of the AuditLogEvent, as a string.
resource: AuditLogEventResourceThe primary object that was affected by this event.