pub struct AuditLogEventActor {
pub actor_type: String,
pub email: String,
pub gid: String,
pub name: String,
}Expand description
The entity that triggered the event. Will typically be a user.
Fields
actor_type: StringThe type of actor.
Can be one of user, asana, asana_support, anonymous, or external_administrator.
email: StringThe email of the actor, if it is a user.
gid: StringGlobally unique identifier of the actor, if it is a user.
name: StringThe name of the actor, if it is a user.