pub struct AuditLogEventContext {
pub api_authentication_method: String,
pub client_ip_address: String,
pub context_type: String,
pub oauth_app_name: String,
pub user_agent: String,
}Expand description
The context from which this event originated.
Fields
api_authentication_method: StringThe authentication method used in the context of an API request.
Only present if the context_type is api. Can be one of cookie, oauth, personal_access_token, or service_account.
client_ip_address: StringThe IP address of the client that initiated the event, if applicable.
context_type: StringThe type of context.
Can be one of web, desktop, mobile, asana_support, asana, email, or api.
oauth_app_name: StringThe name of the OAuth App that initiated the event.
Only present if the api_authentication_method is oauth.
user_agent: StringThe user agent of the client that initiated the event, if applicable.