pub struct DateVariableCompact {
pub description: String,
pub gid: String,
pub name: String,
}Fields
description: StringThe description of what the date variable is used for when instantiating a project.
gid: StringGlobally unique identifier of the date field in the project template. A value of 1 refers to the project start date, while 2 refers to the project due date.
name: StringThe name of the date variable.