pub struct EnumOptionInsertRequest {
pub after_enum_option: String,
pub before_enum_option: String,
pub enum_option: String,
}Fields
after_enum_option: StringAn existing enum option within this custom field after which the new enum option should be inserted. Cannot be provided together with before_enum_option.
before_enum_option: StringAn existing enum option within this custom field before which the new enum option should be inserted. Cannot be provided together with after_enum_option.
enum_option: StringThe gid of the enum option to relocate.