pub struct EnumOptionRequest {
pub enum_option_base: EnumOptionBase,
pub insert_after: Option<String>,
pub insert_before: Option<String>,
}Fields
enum_option_base: EnumOptionBaseinsert_after: Option<String>An existing enum option within this custom field after which the new enum option should be inserted. Cannot be provided together with before_enum_option.
insert_before: Option<String>An existing enum option within this custom field before which the new enum option should be inserted. Cannot be provided together with after_enum_option.