pub struct GoalAddSupportingRelationshipRequest {
pub contribution_weight: f64,
pub insert_after: Option<String>,
pub insert_before: Option<String>,
pub supporting_resource: String,
}Fields
contribution_weight: f64The weight that the supporting resource’s progress will contribute to the supported goal’s progress. This can only be 0 or 1.
insert_after: Option<String>An id of a subgoal of this parent goal. The new subgoal will be added after the one specified here. insert_before and insert_after parameters cannot both be specified. Currently only supported when adding a subgoal.
insert_before: Option<String>An id of a subgoal of this parent goal. The new subgoal will be added before the one specified here. insert_before and insert_after parameters cannot both be specified. Currently only supported when adding a subgoal.
supporting_resource: StringThe gid of the supporting resource to add to the parent goal. Must be the gid of a goal, project, task, or portfolio.