pub struct GoalRelationshipCompact {
pub asana_resource: AsanaResource,
pub contribution_weight: Option<f64>,
pub resource_subtype: Option<String>,
pub supporting_resource: Option<Value>,
}Fields
asana_resource: AsanaResourceA generic Asana Resource, containing a globally unique identifier.
contribution_weight: Option<f64>The weight that the supporting resource’s progress contributes to the supported goal’s progress. This can only be 0 or 1.
resource_subtype: Option<String>The subtype of this resource. Different subtypes retain many of the same fields and behavior, but may render differently in Asana or represent resources with different semantic meaning.
supporting_resource: Option<Value>Trait Implementations
Sourceimpl Clone for GoalRelationshipCompact
impl Clone for GoalRelationshipCompact
Sourcefn clone(&self) -> GoalRelationshipCompact
fn clone(&self) -> GoalRelationshipCompact
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GoalRelationshipCompact
impl Debug for GoalRelationshipCompact
Sourceimpl Default for GoalRelationshipCompact
impl Default for GoalRelationshipCompact
Sourcefn default() -> GoalRelationshipCompact
fn default() -> GoalRelationshipCompact
Returns the “default value” for a type. Read more
Sourceimpl Deref for GoalRelationshipCompact
impl Deref for GoalRelationshipCompact
Sourceimpl DerefMut for GoalRelationshipCompact
impl DerefMut for GoalRelationshipCompact
Sourceimpl<'de> Deserialize<'de> for GoalRelationshipCompact
impl<'de> Deserialize<'de> for GoalRelationshipCompact
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for GoalRelationshipCompact
impl Display for GoalRelationshipCompact