pub struct GoalRemoveSupportingRelationshipRequest {
pub supporting_resource: String,
}Fields
supporting_resource: StringThe gid of the supporting resource to remove from the parent goal. Must be the gid of a goal, project, task, or portfolio.