GoalResponse

Struct GoalResponse 

pub struct GoalResponse {
    pub goal_base: GoalBase,
    pub current_status_update: Option<Value>,
    pub followers: Option<Vec<UserCompact>>,
    pub likes: Option<Vec<Like>>,
    pub metric: Option<Value>,
    pub num_likes: Option<i64>,
    pub owner: Option<Value>,
    pub status: Option<String>,
    pub team: Option<Value>,
    pub time_period: Option<Value>,
    pub workspace: Option<Value>,
}

Fields

goal_base: GoalBasecurrent_status_update: Option<Value>followers: Option<Vec<UserCompact>>

Array of users who are members of this goal.

likes: Option<Vec<Like>>

Array of likes for users who have liked this goal.

metric: Option<Value>num_likes: Option<i64>

The number of users who have liked this goal.

owner: Option<Value>status: Option<String>

The current status of this goal. When the goal is open, its status can be green, yellow, and red to reflect “On Track”, “At Risk”, and “Off Track”, respectively. When the goal is closed, the value can be missed, achieved, partial, or dropped. Note you can only write to this property if metric is set.

team: Option<Value>time_period: Option<Value>workspace: Option<Value>