GoalUpdateRequest

Struct GoalUpdateRequest 

pub struct GoalUpdateRequest {
    pub goal_request_base: GoalRequestBase,
    pub status: Option<String>,
}

Fields

goal_request_base: GoalRequestBasestatus: Option<String>

The current status of this goal. When the goal is open, its status can be green, yellow, and red to reflect “On Track”, “At Risk”, and “Off Track”, respectively. When the goal is closed, the value can be missed, achieved, partial, or dropped. Note you can only write to this property if metric is set.