pub struct Preview {
pub fallback: String,
pub footer: String,
pub header: String,
pub header_link: String,
pub html_text: String,
pub text: String,
pub title: String,
pub title_link: String,
}Expand description
A collection of rich text that will be displayed as a preview to another app.
This is read-only except for a small group of whitelisted apps.
Fields
fallback: StringSome fallback text to display if unable to display the full preview.
Text to display in the footer.
header: StringText to display in the header.
header_link: StringWhere the header will link to.
html_text: StringHTML formatted text for the body of the preview.
text: StringText for the body of the preview.
title: StringText to display as the title.
title_link: StringWhere to title will link to.