pub struct ProjectSaveAsTemplateRequestBody {
pub name: String,
pub public: bool,
pub team: String,
pub workspace: String,
}Fields
name: StringThe name of the new project template.
public: boolSets the project template to public to its team.
team: StringSets the team of the new project template. If the project exists in an organization, specify team and not workspace.
workspace: StringSets the workspace of the new project template. Only specify workspace if the project exists in a workspace.