pub struct ProjectTemplateBase {
pub project_template_compact: ProjectTemplateCompact,
pub color: Option<Value>,
pub description: Option<String>,
pub html_description: Option<String>,
pub owner: Option<Value>,
pub public: Option<bool>,
pub requested_dates: Option<Vec<DateVariableCompact>>,
pub requested_roles: Option<Vec<TemplateRole>>,
pub team: Option<TeamCompact>,
}Fields
project_template_compact: ProjectTemplateCompactcolor: Option<Value>Color of the project template.
description: Option<String>Free-form textual information associated with the project template
html_description: Option<String>The description of the project template with formatting as HTML.
owner: Option<Value>The current owner of the project template, may be null.
public: Option<bool>True if the project template is public to its team.
requested_dates: Option<Vec<DateVariableCompact>>Array of date variables in this project template. Calendar dates must be provided for these variables when instantiating a project.
requested_roles: Option<Vec<TemplateRole>>Array of template roles in this project template. User Ids can be provided for these variables when instantiating a project to assign template tasks to the user.
team: Option<TeamCompact>Trait Implementations
Sourceimpl Clone for ProjectTemplateBase
impl Clone for ProjectTemplateBase
Sourcefn clone(&self) -> ProjectTemplateBase
fn clone(&self) -> ProjectTemplateBase
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProjectTemplateBase
impl Debug for ProjectTemplateBase
Sourceimpl Default for ProjectTemplateBase
impl Default for ProjectTemplateBase
Sourcefn default() -> ProjectTemplateBase
fn default() -> ProjectTemplateBase
Returns the “default value” for a type. Read more
Sourceimpl Deref for ProjectTemplateBase
impl Deref for ProjectTemplateBase
Sourceimpl DerefMut for ProjectTemplateBase
impl DerefMut for ProjectTemplateBase
Sourceimpl<'de> Deserialize<'de> for ProjectTemplateBase
impl<'de> Deserialize<'de> for ProjectTemplateBase
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for ProjectTemplateBase
impl Display for ProjectTemplateBase