pub struct RuleTriggerRequest {
pub action_data: Value,
pub resource: String,
}Fields
action_data: ValueThe dynamic keys and values of the request. These fields are intended to be used in the action for the rule associated with this trigger.
resource: StringThe ID of the resource. For the duration of the beta, this resource is always a task, and this task must exist in the project in which the rule is created.