pub struct StatusUpdateBase {
pub status_update_compact: StatusUpdateCompact,
pub html_text: Option<String>,
pub status_type: String,
pub text: String,
}Fields
status_update_compact: StatusUpdateCompacthtml_text: Option<String>Opt In. The text content of the status update with formatting as HTML.
status_type: StringThe type associated with the status update. This represents the current state of the object this object is on.
text: StringThe text content of the status update.