pub struct StatusUpdateCompact {
pub asana_resource: AsanaResource,
pub resource_subtype: Option<String>,
pub title: Option<String>,
}Fields
asana_resource: AsanaResourceA generic Asana Resource, containing a globally unique identifier.
resource_subtype: Option<String>The subtype of this resource. Different subtypes retain many of the same fields and behavior, but may render differently in Asana or represent resources with different semantic meaning.
The resource_subtypes for status objects represent the type of their parent.
title: Option<String>The title of the status update.