pub struct StoryBase {
pub asana_resource: AsanaResource,
pub created_at: Option<DateTime<Utc>>,
pub html_text: Option<String>,
pub is_pinned: Option<bool>,
pub resource_subtype: Option<String>,
pub sticker_name: Option<String>,
pub text: Option<String>,
}Fields
asana_resource: AsanaResourceA generic Asana Resource, containing a globally unique identifier.
created_at: Option<DateTime<Utc>>The time at which this resource was created.
html_text: Option<String>Opt In. HTML formatted text for a comment. This will not include the name of the creator.
is_pinned: Option<bool>Conditional. Whether the story should be pinned on the resource.
resource_subtype: Option<String>The subtype of this resource. Different subtypes retain many of the same fields and behavior, but may render differently in Asana or represent resources with different semantic meaning.
sticker_name: Option<String>The name of the sticker in this story. null if there is no sticker.
text: Option<String>The plain text of the comment to add. Cannot be used with html_text.