pub struct StoryCompact {
pub asana_resource: AsanaResource,
pub created_at: Option<DateTime<Utc>>,
pub created_by: Option<UserCompact>,
pub resource_subtype: Option<String>,
pub text: Option<String>,
}Fields
asana_resource: AsanaResourceA generic Asana Resource, containing a globally unique identifier.
created_at: Option<DateTime<Utc>>The time at which this resource was created.
created_by: Option<UserCompact>resource_subtype: Option<String>The subtype of this resource. Different subtypes retain many of the same fields and behavior, but may render differently in Asana or represent resources with different semantic meaning.
text: Option<String>Create-only. Human-readable text for the story or comment.
This will not include the name of the creator.
Note: This is not guaranteed to be stable for a given type of story. For example, text for a reassignment may not always say “assigned to …” as the text for a story can both be edited and change based on the language settings of the user making the request.
Use the resource_subtype property to discover the action that created the story.