pub struct TaskAddProjectRequest {
pub insert_after: Option<String>,
pub insert_before: Option<String>,
pub project: String,
pub section: Option<String>,
}Fields
insert_after: Option<String>A task in the project to insert the task after, or null to insert at the beginning of the list.
insert_before: Option<String>A task in the project to insert the task before, or null to insert at the end of the list.
project: StringThe project to add the task to.
section: Option<String>A section in the project to insert the task into. The task will be inserted at the bottom of the section.