pub struct TeamResponse {
pub team_base: TeamBase,
pub description: Option<String>,
pub edit_team_name_or_description_access_level: Option<String>,
pub edit_team_visibility_or_trash_team_access_level: Option<String>,
pub guest_invite_management_access_level: Option<String>,
pub html_description: Option<String>,
pub join_request_management_access_level: Option<String>,
pub member_invite_management_access_level: Option<String>,
pub organization: Option<Value>,
pub permalink_url: Option<String>,
pub team_member_removal_access_level: Option<String>,
pub visibility: Option<String>,
}Fields
team_base: TeamBasedescription: Option<String>Opt In. The description of the team.
edit_team_name_or_description_access_level: Option<String>Controls who can edit team name and description
edit_team_visibility_or_trash_team_access_level: Option<String>Controls who can edit team visibility and trash teams
guest_invite_management_access_level: Option<String>Controls who can accept or deny guest invites for a given team
html_description: Option<String>Opt In. The description of the team with formatting as HTML.
join_request_management_access_level: Option<String>Controls who can accept or deny join team requests for a Membership by Request team
member_invite_management_access_level: Option<String>Controls who can accept or deny member invites for a given team
organization: Option<Value>permalink_url: Option<String>A url that points directly to the object within Asana.
team_member_removal_access_level: Option<String>Controls who can remove team members
visibility: Option<String>The visibility of the team to users in the same organization