OrganizationExportBase

Type Alias OrganizationExportBase 

pub type OrganizationExportBase = OrganizationExportCompact;

Aliased Type

pub struct OrganizationExportBase {
    pub asana_resource: AsanaResource,
    pub created_at: Option<DateTime<Utc>>,
    pub download_url: Option<String>,
    pub organization: Option<WorkspaceCompact>,
    pub state: Option<String>,
}

Fields

asana_resource: AsanaResource

A generic Asana Resource, containing a globally unique identifier.

created_at: Option<DateTime<Utc>>

The time at which this resource was created.

download_url: Option<String>

Download this URL to retreive the full export of the organization in JSON format. It will be compressed in a gzip (.gz) container.

Note: May be null if the export is still in progress or failed. If present, this URL may only be valid for 1 hour from the time of retrieval. You should avoid persisting this URL somewhere and rather refresh on demand to ensure you do not keep stale URLs.

organization: Option<WorkspaceCompact>state: Option<String>

The current state of the export.