UserTaskListBase

Type Alias UserTaskListBase 

pub type UserTaskListBase = UserTaskListCompact;

Aliased Type

pub struct UserTaskListBase {
    pub asana_resource: AsanaResource,
    pub name: Option<String>,
    pub owner: Option<UserCompact>,
    pub workspace: Option<WorkspaceCompact>,
}

Fields

asana_resource: AsanaResource

A generic Asana Resource, containing a globally unique identifier.

name: Option<String>

The name of the user task list.

owner: Option<UserCompact>

The owner of the user task list, i.e. the person whose My Tasks is represented by this resource.

workspace: Option<WorkspaceCompact>

The workspace in which the user task list is located.