pub struct SectionRequest {
pub project: String,
pub name: String,
pub insert_before: Option<String>,
pub insert_after: Option<String>,
}Fields
project: StringCreate-Only The project to create the section in
name: StringThe text to be displayed as the section name. This cannot be an empty string.
insert_before: Option<String>An existing section within this project before which the added section should be inserted. Cannot be provided together with insert_after.
insert_after: Option<String>An existing section within this project after which the added section should be inserted. Cannot be provided together with insert_before.
Implementations
Sourceimpl SectionRequest
impl SectionRequest
pub fn new(project: String, name: String) -> SectionRequest