pub struct GoalBase {
pub asana_resource: AsanaResource,
pub due_on: Option<String>,
pub html_notes: Option<String>,
pub is_workspace_level: Option<bool>,
pub liked: Option<bool>,
pub name: Option<String>,
pub notes: Option<String>,
pub start_on: Option<String>,
}Fields
asana_resource: AsanaResourceA generic Asana Resource, containing a globally unique identifier.
due_on: Option<String>The localized day on which this goal is due. This takes a date with format YYYY-MM-DD.
html_notes: Option<String>The notes of the goal with formatting as HTML.
is_workspace_level: Option<bool>Conditional. This property is only present when the workspace provided is an organization. Whether the goal belongs to the workspace (and is listed as part of the workspace’s goals) or not. If it isn’t a workspace-level goal, it is a team-level goal, and is associated with the goal’s team.
liked: Option<bool>True if the goal is liked by the authorized user, false if not.
name: Option<String>The name of the goal.
notes: Option<String>Free-form textual information associated with the goal (i.e. its description).
start_on: Option<String>The day on which work for this goal begins, or null if the goal has no start date. This takes a date with YYYY-MM-DD format, and cannot be set unless there is an accompanying due date.