pub struct GoalResponse {
pub goal_base: GoalBase,
pub current_status_update: Option<Value>,
pub followers: Option<Vec<UserCompact>>,
pub likes: Option<Vec<Like>>,
pub metric: Option<Value>,
pub num_likes: Option<i64>,
pub owner: Option<Value>,
pub status: Option<String>,
pub team: Option<Value>,
pub time_period: Option<Value>,
pub workspace: Option<Value>,
}Fields
goal_base: GoalBasecurrent_status_update: Option<Value>followers: Option<Vec<UserCompact>>Array of users who are members of this goal.
likes: Option<Vec<Like>>Array of likes for users who have liked this goal.
metric: Option<Value>num_likes: Option<i64>The number of users who have liked this goal.
owner: Option<Value>status: Option<String>The current status of this goal. When the goal is open, its status can be green, yellow, and red to reflect “On Track”, “At Risk”, and “Off Track”, respectively. When the goal is closed, the value can be missed, achieved, partial, or dropped.
Note you can only write to this property if metric is set.
team: Option<Value>time_period: Option<Value>workspace: Option<Value>Trait Implementations
Sourceimpl Clone for GoalResponse
impl Clone for GoalResponse
Sourcefn clone(&self) -> GoalResponse
fn clone(&self) -> GoalResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GoalResponse
impl Debug for GoalResponse
Sourceimpl Default for GoalResponse
impl Default for GoalResponse
Sourcefn default() -> GoalResponse
fn default() -> GoalResponse
Returns the “default value” for a type. Read more
Sourceimpl Deref for GoalResponse
impl Deref for GoalResponse
Sourceimpl DerefMut for GoalResponse
impl DerefMut for GoalResponse
Sourceimpl<'de> Deserialize<'de> for GoalResponse
impl<'de> Deserialize<'de> for GoalResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for GoalResponse
impl Display for GoalResponse