pub struct TaskResponse {
pub task_base: TaskBase,
pub assignee: Option<Value>,
pub assignee_section: Option<Value>,
pub custom_fields: Option<Vec<CustomFieldResponse>>,
pub followers: Option<Vec<UserCompact>>,
pub parent: Option<Value>,
pub permalink_url: Option<String>,
pub projects: Option<Vec<ProjectCompact>>,
pub tags: Option<Vec<TagCompact>>,
pub workspace: Option<Value>,
}Fields
task_base: TaskBaseassignee: Option<Value>assignee_section: Option<Value>custom_fields: Option<Vec<CustomFieldResponse>>Array of custom field values applied to the task. These represent the custom field values recorded on this project for a particular custom field. For example, these custom field values will contain an enum_value property for custom fields of type enum, a text_value property for custom fields of type text, and so on. Please note that the gid returned on each custom field value is identical to the gid of the custom field, which allows referencing the custom field metadata through the /custom_fields/custom_field-gid endpoint.
followers: Option<Vec<UserCompact>>Array of users following this task.
parent: Option<Value>permalink_url: Option<String>A url that points directly to the object within Asana.
projects: Option<Vec<ProjectCompact>>Create-only. Array of projects this task is associated with. At task creation time, this array can be used to add the task to many projects at once. After task creation, these associations can be modified using the addProject and removeProject endpoints.
Array of tags associated with this task. In order to change tags on an existing task use addTag and removeTag.
workspace: Option<Value>Trait Implementations
Sourceimpl Clone for TaskResponse
impl Clone for TaskResponse
Sourcefn clone(&self) -> TaskResponse
fn clone(&self) -> TaskResponse
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more