pub type JobBase = JobCompact;Aliased Type
pub struct JobBase {
pub asana_resource: AsanaResource,
pub new_project: Option<ProjectCompact>,
pub new_project_template: Option<ProjectTemplateCompact>,
pub new_task: Option<Value>,
pub resource_subtype: Option<String>,
pub status: Option<String>,
}Fields
asana_resource: AsanaResourceA generic Asana Resource, containing a globally unique identifier.
new_project: Option<ProjectCompact>new_project_template: Option<ProjectTemplateCompact>new_task: Option<Value>resource_subtype: Option<String>The subtype of this resource. Different subtypes retain many of the same fields and behavior, but may render differently in Asana or represent resources with different semantic meaning.
status: Option<String>The current status of this job. The value is one of: not_started, in_progress, succeeded, or failed.